# coding: utf-8

"""
    VPlex REST API

    A defnition for the next-gen VPlex API  # noqa: E501

    OpenAPI spec version: 0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class DeviceMigrationPayload(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'str',
        'source': 'str',
        'target': 'str',
        'transfer_size': 'int',
        'paused': 'bool'
    }

    attribute_map = {
        'name': 'name',
        'source': 'source',
        'target': 'target',
        'transfer_size': 'transfer_size',
        'paused': 'paused'
    }

    def __init__(self, name=None, source=None, target=None, transfer_size=None, paused=None):  # noqa: E501
        """DeviceMigrationPayload - a model defined in Swagger"""  # noqa: E501

        self._name = None
        self._source = None
        self._target = None
        self._transfer_size = None
        self._paused = None
        self.discriminator = None

        self.name = name
        self.source = source
        self.target = target
        if transfer_size is not None:
            self.transfer_size = transfer_size
        if paused is not None:
            self.paused = paused

    @property
    def name(self):
        """Gets the name of this DeviceMigrationPayload.  # noqa: E501


        :return: The name of this DeviceMigrationPayload.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this DeviceMigrationPayload.


        :param name: The name of this DeviceMigrationPayload.  # noqa: E501
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def source(self):
        """Gets the source of this DeviceMigrationPayload.  # noqa: E501


        :return: The source of this DeviceMigrationPayload.  # noqa: E501
        :rtype: str
        """
        return self._source

    @source.setter
    def source(self, source):
        """Sets the source of this DeviceMigrationPayload.


        :param source: The source of this DeviceMigrationPayload.  # noqa: E501
        :type: str
        """
        if source is None:
            raise ValueError("Invalid value for `source`, must not be `None`")  # noqa: E501

        self._source = source

    @property
    def target(self):
        """Gets the target of this DeviceMigrationPayload.  # noqa: E501


        :return: The target of this DeviceMigrationPayload.  # noqa: E501
        :rtype: str
        """
        return self._target

    @target.setter
    def target(self, target):
        """Sets the target of this DeviceMigrationPayload.


        :param target: The target of this DeviceMigrationPayload.  # noqa: E501
        :type: str
        """
        if target is None:
            raise ValueError("Invalid value for `target`, must not be `None`")  # noqa: E501

        self._target = target

    @property
    def transfer_size(self):
        """Gets the transfer_size of this DeviceMigrationPayload.  # noqa: E501

        Number in Byte. Must be a multiple of 4K. Range: 40KB - 128M. Default: 128KB(131072).   # noqa: E501

        :return: The transfer_size of this DeviceMigrationPayload.  # noqa: E501
        :rtype: int
        """
        return self._transfer_size

    @transfer_size.setter
    def transfer_size(self, transfer_size):
        """Sets the transfer_size of this DeviceMigrationPayload.

        Number in Byte. Must be a multiple of 4K. Range: 40KB - 128M. Default: 128KB(131072).   # noqa: E501

        :param transfer_size: The transfer_size of this DeviceMigrationPayload.  # noqa: E501
        :type: int
        """

        self._transfer_size = transfer_size

    @property
    def paused(self):
        """Gets the paused of this DeviceMigrationPayload.  # noqa: E501


        :return: The paused of this DeviceMigrationPayload.  # noqa: E501
        :rtype: bool
        """
        return self._paused

    @paused.setter
    def paused(self, paused):
        """Sets the paused of this DeviceMigrationPayload.


        :param paused: The paused of this DeviceMigrationPayload.  # noqa: E501
        :type: bool
        """

        self._paused = paused

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DeviceMigrationPayload):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
